@@ -1,5 +1,4 @@
-gexmap <-
-function (genome = "homosapiens", scale = "", source = "", res = "", isGO = FALSE, isMAP = TRUE, lim_chi = 5, global_test_choice = 4, pcorrd = 1, pcorrv = 1)
+gexmap<-function (genome = "homosapiens", scale = "", source = "", res = "", isGO = FALSE, isMAP = TRUE, lim_chi = 5, global_test_choice = 4, pcorrd = 1, pcorrv = 1)
 {
     write("###############################################################################", file = "")
     write("#                                                                             #", file = "")
@@ -54,6 +53,7 @@ function (genome = "homosapiens", scale = "", source = "", res = "", isGO = FALS
    ###############################################################################
   
     write("Upload of list to analyze", file = "")
+    flush.console()
     if (source == "test")
     {
         data(list)
@@ -68,6 +68,7 @@ function (genome = "homosapiens", scale = "", source = "", res = "", isGO = FALS
     colnames(list) = names
     
     write(paste("Loading the ", genome, " genome Rdata file", sep = ""), file = "")
+    flush.console()
     if (source == "test")
     {
         data(data)
@@ -76,8 +77,89 @@ function (genome = "homosapiens", scale = "", source = "", res = "", isGO = FALS
         data = gexload.data(source, genome)
     }
     
-    list.ENS = gexload.corr(data, list, scale, source, res)
+    #
+    ######################################
+    # upload of correspondances file
+    ######################################
 
+    mtype = unlist(strsplit(colnames(list)[1], ","))[2]
+    ttype = unlist(strsplit(colnames(list)[1], ","))[1]
+    if (length(agrep(",", colnames(list)[1], ignore.case = TRUE)) != 0)
+    {
+        write(paste("Loading the ", ttype, " ", mtype, " file", sep = ""), file = "")
+        Rdata.dir = file.path(paste(source, ttype, "-", mtype, ".Rdata", sep = ""))
+    } else
+    {
+        write(paste("Loading the ", ttype, ".Rdata file", sep = ""), file = "")
+        Rdata.dir = file.path(paste(source, ttype, ".Rdata", sep = ""))
+    }
+
+    if (source == "test")
+    {
+        data(corr)
+    } else
+    {
+        if (!file.exists(Rdata.dir))
+        {
+            write(sprintf("ERROR: file %s does not exist in the default directory", source), file = "")
+            write(paste("Load manually the ", ttype, "-", mtype,".Rdata file", sep = ""), file = "")
+            flush.console()
+            load(file = file.choose())
+        } else
+        {
+            load(file = Rdata.dir)
+            write("Rdata file Loaded")
+        }
+    }
+
+    ######################################
+    # Matrix of correspondences
+    ######################################
+    
+    absents_corr = matrix(0, ncol = 1, nrow = 0)  #matrix of the identifiers not found in the data.Rdata matrix
+    write("Looking for correspondences", file = "")
+    #deb = format(Sys.time(), "%H:%M:%S")
+    id = as.matrix(unlist(apply(list, 1, function(x) as.matrix(corr[corr[, "probes"] == x[1], "ensembl"]))))
+    #write(paste("debut:", deb, ", fin:", format(Sys.time(), "%H:%M:%S"), sep=""), file="")
+    id = cbind(id, as.matrix(rep(1, nrow(id))))
+    
+    write("Correspondences OK", file = "")
+    if (nrow(absents_corr) != 0)
+    {
+      write.table(absents_corr, row.names = FALSE, sep = "\t", file = paste(res, "absents_corr.txt", sep = ""))
+      write(paste(nrow(absents_corr), " identifiers unknown with no ENSEMBL correspondences have been placed in the absents_corr.txt file", sep = ""), file = "")
+    }
+
+    # Suppression of the ENSG00000000000 identifiers which corresponds to unidentified probes
+    id = as.matrix(id[id[, 1] != "ENSG00000000000", ])
+    write(paste("Nbre of identified probes=", nrow(id), sep = ""), file = "")
+       
+   ###############################################################################
+   #                                                                             #
+   #                               VALIDATION                                    #
+   #                                                                             #
+   ###############################################################################
+
+    # looking for localisation information
+    write("Collecting localisation data", file = "")
+    tbl_scale = matrix(0, ncol = 1, nrow = nrow(id))
+    absents_data = matrix(0, ncol = 1, nrow = 0)
+    id_map = matrix(0, ncol=ncol(data), nrow=0)
+    
+    for(K in 1:nrow(id))
+    {
+      if(is.null(nrow(data[data[,"ensembl"]==id[K,1],])))  id_map = rbind(id_map, t(data[data[,"ensembl"]==id[K,1],]))
+    }
+    
+    #id_map = rbind(id_map, apply(id, 1, function(x) t(as.matrix(data[data[,"ensembl"]==x[1],]))))
+    id_map =  cbind(id_map, as.matrix(rep(1, nrow(id_map))))
+    colnames(id_map) = c("chr", "cytoband", "ensembl", "name", "m", "GO", "expression")        
+    list.ENS = id_map[,c("chr", "m", "cytoband", "name", "ensembl", "GO", "expression")]
+    
+    write("Localisation data OK", file = "")
+    write("Saving data", file = "")
+    write.table(id_map, row.names = FALSE, sep = "\t", file = file.path(paste(res, "report.txt", sep = "")))
+    
    ######################################################################################################
    #                                                                                                    #
    #                             FORMATTING GENOME TABLE                                                #
@@ -186,3 +268,5 @@ function (genome = "homosapiens", scale = "", source = "", res = "", isGO = FALS
     }
 }
 
+#gexmap(genome="homosapiens", scale="", source="", res="", isGO=F, isMAP=TRUE, lim_chi=5, global_test_choice=4, pcorrd=1, pcorrv=1)
+#genome="homosapiens"; scale=""; source=""; res=""; isGO=F; isMAP=TRUE; lim_chi=5; global_test_choice=4; pcorrd=1; pcorrv=1
